@@ -19,8 +19,6 @@
 
 package org.apache.pulsar.reactive.client.adapter;
 
-import java.util.Locale;
-
 import org.apache.pulsar.client.api.PulsarClient;
 import org.apache.pulsar.client.api.PulsarClientException;
 import org.testcontainers.containers.PulsarContainer;
@@ -46,21 +44,7 @@ final class SingletonPulsarContainer {
 	}
 
 	static DockerImageName getPulsarImage() {
-		return isRunningOnMacM1() ? getMacM1PulsarImage() : getStandardPulsarImage();
-	}
-
-	private static boolean isRunningOnMacM1() {
-		String osName = System.getProperty("os.name").toLowerCase(Locale.ENGLISH);
-		String osArchitecture = System.getProperty("os.arch").toLowerCase(Locale.ENGLISH);
-		return osName.contains("mac") && osArchitecture.equals("aarch64");
-	}
-
-	private static DockerImageName getStandardPulsarImage() {
-		return DockerImageName.parse("apachepulsar/pulsar:2.11.0");
-	}
-
-	private static DockerImageName getMacM1PulsarImage() {
-		return DockerImageName.parse("kezhenxu94/pulsar").asCompatibleSubstituteFor("apachepulsar/pulsar");
+		return DockerImageName.parse("apachepulsar/pulsar:3.1.0");
 	}
 
 }
